from ..utils import Games



class Bedwars:

	def __init__(self, data):
		self.name = "Bedwars"
		self.solo = Solo(data)
		self.games = Games(
			data.get("player", {}).get("stats", {}).get("Bedwars", {}).get("games_played_bedwars"),
			data.get("player", {}).get("stats", {}).get("Bedwars", {}).get("wins_bedwars"),
			data.get("player", {}).get("stats", {}).get("Bedwars", {}).get("losses_bedwars")
			)
		self.beds = Beds(
			data.get("player", {}).get("stats", {}).get("Bedwars", {}).get("beds_broken_bedwars"),
			data.get("player", {}).get("stats", {}).get("Bedwars", {}).get("beds_lost_bedwars")
			)


#Returns the broken/destroyed Beds
class Beds:
	def __init__(self, broken, lost):
		self.name = "Beds destroyed/broken"
		self.destroyed = broken
		self.lost = lost


#Bedwars Solo rounds
class Solo:

	def __init__(self, data):

		self.name = "Solo"
		self.games = Games(
			data.get("player", {}).get("stats", {}).get("Bedwars", {}).get("eight_one_games_played_bedwars", 0),
			data.get("player", {}).get("stats", {}).get("Bedwars", {}).get("eight_one_wins_bedwars", 0),
			data.get("player", {}).get("stats", {}).get("Bedwars", {}).get("eight_one_losses_bedwars", 0),
			)

		self.beds = Beds(
			data.get("player", {}).get("stats", {}).get("Bedwars", {}).get("eigth_one_beds_broken_bedwars", 0),
			data.get("player", {}).get("stats", {}).get("Bedwars", {}).get("eight_one_beds_lost_bedwars", 0)
			) 





class APIError(Exception):
	def __init__(self, error):
		self.error = error

class InvalidAPIKeyError(Exception):
	def __init__(self, error):
		self.error = error


class InvalidPlayerNameError(Exception):
	pass

class NoInputError(Exception):
	pass


from .exceptions import APIError
from .games import Bedwars
from .profile import *





class Player:

	def __init__(self, data):

		self.data = data
		self.name = self.data.get("player", {}).get("displayname")
		self.uuid = self.data.get("player", {}).get("uuid")
		self.rank = Rank(data)
		self.bedwars = Bedwars(data)


from .exceptions import APIError

ranks = {
    "NONE": None,
    "VIP": "VIP",
    "VIP_PLUS": "VIP+",
    "MVP": "MVP",
    "MVP_PLUS": "MVP+",
    "SUPERSTAR": "MVP++",
    "YOUTUBER": "YOUTUBE",
    "PIG+++": "PIG+++",
    "BUILD TEAM": "BUILD TEAM",
    "HELPER": "HELPER",
    "MODERATOR": "MOD",
    "ADMIN": "ADMIN",
    "SLOTH": "SLOTH",
    "OWNER": "OWNER"
}

def rankname(rank, prefix_raw, monthly_package_rank, new_package_rank, package_rank):
	real_rank = None
	if prefix_raw:
		prefix = re.sub(r"§.", "", prefix_raw)[1:-1]
	    # prefixes all start and end with brackets, and have minecraft color codes, this is to remove color codes and
    	# brackets			real_rank = ranks.get(prefix, prefix)
	elif rank and rank != "NORMAL" and not real_rank:
		real_rank = ranks.get(rank, rank)
	elif (monthly_package_rank and monthly_package_rank != "NONE") and not real_rank:
	    # WHY DOES IT EXIST IF IT'S NONE HYPIXEL WHY
	    real_rank = ranks.get(monthly_package_rank, monthly_package_rank)
	elif new_package_rank and not real_rank:
		real_rank = ranks.get(new_package_rank, new_package_rank)
	elif package_rank and not real_rank:
		real_rank = ranks.get(package_rank, package_rank)
	return real_rank
	
class Rank:

	def __init__(self, data):

		self.data = data
		self.name = rankname(
			data.get("player", {}).get("rank"),
			data.get("player", {}).get("prefix"),
			data.get("player", {}).get("monthlyPackageRank"),
			data.get("player", {}).get("newPackageRank"),
			data.get("player", {}).get("packageRank")
			)




import requests
import asyncio
import json

from .exceptions import APIError, NoInputError
from .utils import key_check
from .Mojang import get_uuid
from .hypixelplayer import Player

HYPIXEL_API = "https://api.hypixel.net"


class get_player:

	def __init__(self, api):
		self.api = api


	def get(self, name=None, uuid=None):

		if name == None and uuid == None:
			raise NoInputError

		if not name == None:
			uuid = get_uuid(name)
		response = requests.get(f"{HYPIXEL_API}/player?key=d44a57f7-ebe1-4b05-9370-9db9c94d9464&uuid={uuid}")
		json = response.json()

		if not json["success"]:

			raise APIError(self.api)
		else:
			return Player(json)


import requests
import json
from .exceptions import InvalidPlayerNameError

MOJANG_API = "https://api.mojang.com"

def get_uuid(name):
	response = requests.get(f"{MOJANG_API}/users/profiles/minecraft/{name}")
	json = response.json()
	try:
		return json["id"]
	except KeyError:
		raise InvalidPlayerNameError
		